import os
from pathlib import Path
from typing import Optional, ClassVar
from pydantic_settings import BaseSettings

# Create DB directory path
DB_PATH = Path("/projects/weatherdataapi-2z0ghm") / "app" / "storage" / "db"
DB_PATH.mkdir(parents=True, exist_ok=True)

class Settings(BaseSettings):
    API_V1_STR: str = "/api/v1"
    PROJECT_NAME: str = "Weather Data API"

    # Database configuration
    DB_DIR: ClassVar[Path] = DB_PATH
    SQLALCHEMY_DATABASE_URL: str = f"sqlite:///{DB_PATH}/db.sqlite"
    
    # OpenWeatherMap API configuration
    OPENWEATHERMAP_API_KEY: Optional[str] = os.getenv("OPENWEATHERMAP_API_KEY")
    OPENWEATHERMAP_API_URL: str = "https://api.openweathermap.org/data/2.5"
    
    class Config:
        case_sensitive = True

settings = Settings()